@@ -1,17 +1,18 @@
 # encoding=UTF-8
 
-# Copyright © 2008-2011 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2008-2015 Jakub Wilk <jwilk@jwilk.net>
 #
-# This package is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; version 2 dated June, 1991.
+# This file is part of djvusmooth.
 #
-# This package is distributed in the hope that it will be useful, but
-# WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-# General Public License for more details.
+# djvusmooth is free software; you can redistribute it and/or modify it
+# under the terms of the GNU General Public License version 2 as published
+# by the Free Software Foundation.
+#
+# djvusmooth is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+# FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
+# more details.
 
-import pkgconfig
 import os.path
 import subprocess
 import threading
@@ -19,10 +20,11 @@ import threading
 from djvu.sexpr import Expression, Symbol
 
 djvused_path = None
-if os.name =='nt':
+if os.name == 'nt':
     from . import dependencies
     djvused_path = os.path.join(dependencies.djvulibre_path, 'djvused.exe')
 else:
+    from . import pkgconfig
     try:
         djvulibre_bin_path = os.path.join(pkgconfig.Package('ddjvuapi').variable('exec_prefix'), 'bin')
     except (IOError, OSError):
@@ -33,17 +35,19 @@ if djvused_path is None or not os.path.isfile(djvused_path):
     # Let's hope it's within $PATH...
     djvused_path = 'djvused'
 
-DJVUSED_PATH = djvused_path
-
 def _djvused_usability_check():
     try:
-        djvused = subprocess.Popen([DJVUSED_PATH], stdout = subprocess.PIPE, stderr = subprocess.PIPE)
+        djvused = subprocess.Popen(
+            [djvused_path],
+            stdout=subprocess.PIPE,
+            stderr=subprocess.PIPE
+        )
         djvused.communicate()
         if djvused.returncode == 10:
             return
     except (IOError, OSError):
         pass
-    raise IOError('%r does not seem to be usable' % DJVUSED_PATH)
+    raise IOError('{path!r} does not seem to be usable'.format(path=djvused_path))
 
 _djvused_usability_check()
 
@@ -52,7 +56,7 @@ class IOError(IOError):
 
 class StreamEditor(object):
 
-    def __init__(self, file_name, autosave = False):
+    def __init__(self, file_name, autosave=False):
         self._file_name = file_name
         self._commands = []
         self._autosave = autosave
@@ -123,7 +127,7 @@ class StreamEditor(object):
     def set_page_title(self, title):
         self._add('set-page-title %s' % Expression(title))
 
-    def save_page(self, file_name, include = False):
+    def save_page(self, file_name, include=False):
         command = 'save-page'
         if include:
             command += '-with'
@@ -139,16 +143,23 @@ class StreamEditor(object):
         self._add('save')
 
     def _reader_thread(self, fo, result):
-        result[0] = fo.read(),
+        result[0] = fo.read()
 
-    def _execute(self, commands, save = False):
-        args = [DJVUSED_PATH]
+    def _execute(self, commands, save=False):
+        args = [djvused_path]
         if save:
             args += '-s',
         args += self._file_name,
-        djvused = subprocess.Popen(args, stdin = subprocess.PIPE, stdout = subprocess.PIPE, stderr = subprocess.PIPE)
+        djvused = subprocess.Popen(args,
+            stdin=subprocess.PIPE,
+            stdout=subprocess.PIPE,
+            stderr=subprocess.PIPE
+        )
         result = [None]
-        reader_thread = threading.Thread(target = self._reader_thread, args = (djvused.stdout, result))
+        reader_thread = threading.Thread(
+            target=self._reader_thread,
+            args=(djvused.stdout, result)
+        )
         reader_thread.setDaemon(True)
         reader_thread.start()
         stdin = djvused.stdin
@@ -163,8 +174,8 @@ class StreamEditor(object):
 
     def commit(self):
         try:
-            return self._execute(self._commands, save = self._autosave)
+            return self._execute(self._commands, save=self._autosave)
         finally:
             self._commands = []
 
-# vim:ts=4 sw=4 et
+# vim:ts=4 sts=4 sw=4 et
