@@ -92,7 +92,8 @@ class FitWidthZoom(Zoom):
     def rezoom_on_resize(self):
         return True
 
-    def get_page_screen_size(self, page_job, (viewport_width, viewport_height)):
+    def get_page_screen_size(self, page_job, viewport_size):
+        (viewport_width, viewport_height) = viewport_size
         real_width, real_height = (page_job.width, page_job.height)
         ratio = 1.0 * real_height / real_width
         return (viewport_width, int(viewport_width * ratio))
@@ -102,7 +103,8 @@ class FitPageZoom(Zoom):
     def rezoom_on_resize(self):
         return True
 
-    def get_page_screen_size(self, page_job, (viewport_width, viewport_height)):
+    def get_page_screen_size(self, page_job, viewport_size):
+        (viewport_width, viewport_height) = viewport_size
         real_width, real_height = (page_job.width, page_job.height)
         ratio = 1.0 * real_height / real_width
         screen_height = int(viewport_width * ratio)
@@ -250,7 +252,7 @@ class NodeShape(wx.lib.ogl.RectangleShape):
 
     def _update_node_size(self):
         x, y, w, h = self.GetX(), self.GetY(), self.GetWidth(), self.GetHeight()
-        screen_rect = x - w//2, y - h//2, w, h
+        screen_rect = (x - w // 2, y - h // 2, w, h)
         self._node.rect = self._xform_real_to_screen.inverse(screen_rect)
 
     def OnMovePost(self, dc, x, y, old_x, old_y, display):
@@ -487,11 +489,11 @@ class PageWidget(wx.lib.ogl.ShapeCanvas):
         # TODO: something lighter
 
     def _on_shape_selected(self, shape):
-        shape.select(notify=False)  # in case it was selected elsewhere
+        shape.select(notify=False)  # if it was selected elsewhere
         self._current_shape = shape
 
     def _on_shape_deselected(self, shape):
-        shape.deselect(notify=False)  # in case it was selected elsewhere
+        shape.deselect(notify=False)  # if it was selected elsewhere
         self._current_shape = None
 
     def on_parent_resize(self, event):
