@@ -2,14 +2,16 @@
 
 # Copyright © 2008-2014 Jakub Wilk <jwilk@jwilk.net>
 #
-# This package is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; version 2 dated June, 1991.
+# This file is part of djvusmooth.
 #
-# This package is distributed in the hope that it will be useful, but
-# WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-# General Public License for more details.
+# djvusmooth is free software; you can redistribute it and/or modify it
+# under the terms of the GNU General Public License version 2 as published
+# by the Free Software Foundation.
+#
+# djvusmooth is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+# FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
+# more details.
 
 '''
 Models for hidden text.
@@ -199,7 +201,7 @@ class LeafNode(Node):
         return property(get, set)
 
     def remove_child(self, child):
-        raise TypeError('%r is not having children' % (self,))
+        raise TypeError('{0!r} cannot have children'.format(self))
 
     def strip(self, zone_type):
         if self.type <= zone_type:
@@ -363,7 +365,7 @@ class PageText(object):
         return property(get, set)
 
     def strip(self, zone_type):
-        zone_type = djvu.const.get_text_zone_type(zone_type) # ensure it's not a plain Symbol
+        zone_type = djvu.const.get_text_zone_type(zone_type)  # ensure it's not a plain Symbol
         if self._root is None:
             return
         stripped_root = self._root.strip(zone_type)
@@ -396,10 +398,12 @@ class PageText(object):
             callback.notify_node_children_change(node)
 
     def notify_node_select(self, node):
-        for callback in self._callbacks: callback.notify_node_select(node)
+        for callback in self._callbacks:
+            callback.notify_node_select(node)
 
     def notify_node_deselect(self, node):
-        for callback in self._callbacks: callback.notify_node_deselect(node)
+        for callback in self._callbacks:
+            callback.notify_node_deselect(node)
 
     def notify_tree_change(self):
         self._dirty = True
@@ -446,4 +450,4 @@ def _get_leafs(node):
 
 __all__ = ['Text', 'PageText']
 
-# vim:ts=4 sw=4 et
+# vim:ts=4 sts=4 sw=4 et
