@@ -2,14 +2,18 @@
 
 # Copyright © 2008-2014 Jakub Wilk <jwilk@jwilk.net>
 #
-# This package is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; version 2 dated June, 1991.
+# This file is part of djvusmooth.
 #
-# This package is distributed in the hope that it will be useful, but
-# WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-# General Public License for more details.
+# djvusmooth is free software; you can redistribute it and/or modify it
+# under the terms of the GNU General Public License version 2 as published
+# by the Free Software Foundation.
+#
+# djvusmooth is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+# FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
+# more details.
+
+from __future__ import print_function
 
 import itertools
 
@@ -105,7 +109,7 @@ def linearize_for_import(expr):
 
 def export(sexpr, stream):
     for line in linearize_for_export(sexpr):
-        print >>stream, line
+        print(line, file=stream)
 
 def import_(sexpr, stdin):
     exported = tuple(linearize_for_export(sexpr))
@@ -138,4 +142,4 @@ __all__ = [
     'NothingChanged', 'CharacterZoneFound', 'LengthChanged'
 ]
 
-# vim:ts=4 sw=4 et
+# vim:ts=4 sts=4 sw=4 et
